<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add cta section
$wp_customize->add_section( 'mega_tour_pro_cta_section', array(
	'title'             => esc_html__( 'Call To Action','mega-tour-pro' ),
	'description'       => esc_html__( 'cta Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback'   => 'mega_tour_pro_is_cta_panel_enable',

) );

// cta content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_cta_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// cta sub title control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_sub_title]', array(
    'default'           => $options['cta_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[cta_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_cta_section',
	'active_callback' 	=> 'mega_tour_pro_is_cta_section_enable',
	'type'				=> 'text',
) );


// cta content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_content_type]', array(
    'default'          	=> $options['cta_content_type'],
    'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[cta_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
    'section'           => 'mega_tour_pro_cta_section',
    'type'				=> 'select',
    'active_callback' 	=> 'mega_tour_pro_is_cta_section_enable',
    'choices'			=> mega_tour_pro_cta_content_type(),
) );


// cta title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_cta_section',
	'active_callback' 	=> 'mega_tour_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[cta_title]', array(
		'selector'            => '#call-to-action .wrapper .entry-header h2.entry-title',
		'settings'            => 'mega_tour_pro_theme_options[cta_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_cta_title_partial',
    ) );
}

// cta description setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[cta_description]', array(
	'label'           	=> esc_html__( 'Description', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_cta_section',
	'active_callback' 	=> 'mega_tour_pro_is_cta_section_content_custom_enable',
	'type'				=> 'textarea',
) );

$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_content_page]', array(
    'sanitize_callback' => 'mega_tour_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[cta_content_page]', array(
    'label'             => esc_html__( 'Select Page', 'mega-tour-pro' ),
    'section'           => 'mega_tour_pro_cta_section',
    'choices'			=> mega_tour_pro_page_choices(),
    'active_callback'	=> 'mega_tour_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_content_post]', array(
    'sanitize_callback' => 'mega_tour_pro_sanitize_page',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[cta_content_post]', array(
    'label'             => esc_html__( 'Select posts', 'mega-tour-pro' ),
    'section'           => 'mega_tour_pro_cta_section',
    'choices'			=> mega_tour_pro_post_choices(),
    'active_callback'	=> 'mega_tour_pro_is_cta_section_content_post_enable',
) ) );

//cta background image setting and control.
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_background_image]', array(
    'default'           => $options['cta_background_image'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mega_tour_pro_theme_options[cta_background_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'mega-tour-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mega-tour-pro' ), 1920, 550 ),
		'section'     		=> 'mega_tour_pro_cta_section',
		'active_callback'	=> 'mega_tour_pro_is_cta_section_enable',
) ) );

// cta read more setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_read_more]', array(
	'default'			=> $options['cta_read_more'],
    'sanitize_callback' => 'sanitize_text_field',
    'transport'         =>'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[cta_read_more]', array(
	'label'           	=> esc_html__( 'Read More Text', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_cta_section',
	'active_callback' 	=> 'mega_tour_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[cta_read_more]', array(
		'selector'            => '#call-to-action .wrapper .read-more a.btn',
		'settings'            => 'mega_tour_pro_theme_options[cta_read_more]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_cta_read_more_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[cta_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[cta_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_cta_section',
	'active_callback' 	=> 'mega_tour_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );
