<?php
/**
 * Popular Destination Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Popular Destination section
$wp_customize->add_section( 'mega_tour_pro_popular_destination_section', array(
	'title'             => esc_html__( 'Popular Destination','mega-tour-pro' ),
	'description'       => esc_html__( 'Popular Destination Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback' 	=> 'mega_tour_pro_is_popular_destination_panel_enable',

) );

// Popular Destination content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_section_enable]', array(
	'default'			=> 	$options['popular_destination_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[popular_destination_section_enable]', array(
	'label'             => esc_html__( 'Popular Destination Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// popular destination sub title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_sub_title]', array(
	'default'			=> $options['popular_destination_sub_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[popular_destination_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_popular_destination_section',
	'active_callback' 	=> 'mega_tour_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// popular destination title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_title]', array(
	'default'			=> $options['popular_destination_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[popular_destination_title]', array(
	'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_popular_destination_section',
	'active_callback' 	=> 'mega_tour_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[popular_destination_title]', array(
		'selector'            => '#popular-destinations .section-header h2.section-title',
		'settings'            => 'mega_tour_pro_theme_options[popular_destination_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_popular_destination_title_partial',
    ) );
}

// Popular Destination column type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_column_type]', array(
	'default'          	=> $options['popular_destination_column_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[popular_destination_column_type]', array(
	'label'             => esc_html__( 'Column Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_popular_destination_section_enable',
	'choices'			=> array(
		3	=> esc_html__( 'Column Three', 'mega-tour-pro' ),
		4	=> esc_html__( 'Column Four', 'mega-tour-pro' ),
		5	=> esc_html__( 'Column Five', 'mega-tour-pro' ),
		),
) );

//Popular Destination post count number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_count]', array(
	'default'          	=> $options['popular_destination_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_popular_destination_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[popular_destination_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'active_callback'   => 'mega_tour_pro_is_popular_destination_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Popular Destination content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_content_type]', array(
	'default'          	=> $options['popular_destination_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[popular_destination_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_popular_destination_section_enable',
	'choices'			=> mega_tour_pro_popular_destination_content_type(),
) );

for ( $i=1; $i <= $options['popular_destination_count']; $i++ ) { 
	// Popular deatination pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[popular_destination_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_popular_destination_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_page_enable',
	) ) );

	// Popular deatination posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[popular_destination_content_post_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select posts %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_popular_destination_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_post_enable',
	) ) );

	// popular_destination trips drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[popular_destination_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_popular_destination_section',
		'choices'			=> mega_tour_pro_trip_choices(),
		'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_trip_enable',
	) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[popular_destination_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[popular_destination_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[popular_destination_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[popular_destination_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[popular_destination_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[popular_destination_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[popular_destination_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[popular_destination_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_popular_destination_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_popular_destination_section_content_destination_enable'
) ) );

// Popular deatination btn label setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[popular_destination_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_destination_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[popular_destination_btn_label]', array(
	'label'           	=> esc_html__( 'Popular Destination Button Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_popular_destination_section',
	'active_callback' 	=> 'mega_tour_pro_is_popular_destination_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[popular_destination_btn_label]', array(
		'selector'            => '#popular-destinations .popular-destination-wrapper .bottom-details .read-more a.btn',
		'settings'            => 'mega_tour_pro_theme_options[popular_destination_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_popular_destination_btn_label_partial',
    ) );
}
