<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'mega_tour_pro_service_section', array(
	'title'             => esc_html__( 'Services','mega-tour-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
	'active_callback' 	=> 'mega_tour_pro_is_service_panel_enable',
) );

// Service content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'priority' => 1,
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );
	// service title setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['service_title'],
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[service_title]', array(
		'label'           	=> esc_html__( 'Title', 'mega-tour-pro' ),
		'section'        	=> 'mega_tour_pro_service_section',
		'active_callback' 	=> 'mega_tour_pro_is_service_business_section_enable',
		'type'				=> 'text',
	) );

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[service_title]', array(
			'selector'            => '#business-services .business-section-header h2',
			'settings'            => 'mega_tour_pro_theme_options[service_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'mega_tour_pro_service_title_partial',
		) );
	}

	// service description setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_description]', array(
		'sanitize_callback' => 'sanitize_textarea_field',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'mega_tour_pro_theme_options[service_description]', array(
		'label'           	=> esc_html__( 'Description', 'mega-tour-pro' ),
		'section'        	=> 'mega_tour_pro_service_section',
		'active_callback' 	=> 'mega_tour_pro_is_service_business_section_enable',
		'type'				=> 'textarea',
	) );

		// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[service_description]', array(
			'selector'            => '#business-services .business-section-header p',
			'settings'            => 'mega_tour_pro_theme_options[service_description]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'mega_tour_pro_service_description_partial',
		) );
	}

// Trip Search content enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[trip_search_enable]', array(
	'default'			=> 	$options['trip_search_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[trip_search_enable]', array(
	'label'             => esc_html__( 'Trip Search Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'active_callback' 	=> 'mega_tour_pro_is_trip_search_enable',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );


// Trip search title setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[trip_search_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	'default'			=> $options['trip_search_title']
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[trip_search_title]', array(
	'label'           	=> esc_html__( 'Trip Search Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_service_section',
	'active_callback' 	=> 'mega_tour_pro_is_trip_search_title_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_pro_theme_options[trip_search_title]', array(
		'selector'            => '#travel-search-section h2',
		'settings'            => 'mega_tour_pro_theme_options[trip_search_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_pro_trip_search_title_partial',
    ) );
}


// Service count number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_service_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'active_callback'   => 'mega_tour_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_service_section_enable',
	'choices'			=> mega_tour_pro_service_content_type(),
) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[service_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_service_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_service_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[service_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_service_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_service_section_content_post_enable',
	) ) );


	//Service icon setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control('mega_tour_pro_theme_options[service_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'mega-tour-pro' ), $i ),
		'description'       => sprintf( '%1$s <a href="%2$s" target="_blank">  %3$s </a> </br> %4$s', esc_html__( 'Get the icon name from', 'mega-tour-pro' ),esc_url('https://fontawesome.com/v4.7.0/'), esc_html__( 'Font Awesome v4.7.0', 'mega-tour-pro' ), esc_html('e.g : fa-bar-chart-o')),
		'section'           => 'mega_tour_pro_service_section',
		'type'				=>'text',
		'active_callback'	=> 'mega_tour_pro_is_service_business_section_enable',
	) );

	// service hr setting and control
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Customize_Horizontal_Line( $wp_customize, 'mega_tour_pro_theme_options[service_hr_'. $i .']',
		array(
			'section'         => 'mega_tour_pro_service_section',
			'active_callback' => 'mega_tour_pro_is_service_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_service_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[service_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[service_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_service_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[service_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[service_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_service_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[service_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[service_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_service_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_service_section_content_destination_enable'
) ) );

// Service btn label setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[service_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	'default'			=> $options['service_btn_label']
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[service_btn_label]', array(
	'label'           	=> esc_html__( 'Service Button Title', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_service_section',
	'active_callback' 	=> 'mega_tour_pro_is_service_btn_section_enable',
	'type'				=> 'text',
) );

/**
 * Business Customizer Options
 */
