<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'mega_tour_pro_slider_section', array(
	'title'             => esc_html__( 'Main Slider','mega-tour-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'mega-tour-pro' ),
	'panel'             => 'mega_tour_pro_front_page_panel',
) );

// Slider section enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
) ) );

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_autoplay]', array(
	'default'			=> 	$options['slider_autoplay'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Pro_Switch_Control( $wp_customize, 'mega_tour_pro_theme_options[slider_autoplay]', array(
	'label'             => esc_html__( 'Auto Play Enable', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'on_off_label' 		=> mega_tour_pro_switch_options(),
	'active_callback' 	=> 'mega_tour_pro_is_slider_section_enable',
) ) );

// Slider post count number control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_number_range',
	'validate_callback' => 'mega_tour_pro_validate_slider_count',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'mega-tour-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 5. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'active_callback'   => 'mega_tour_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 5,
		'style' => 'width: 100px;'
		),
) );

// Slider content type control and setting
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'mega_tour_pro_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_pro_is_slider_section_enable',
	'choices'			=> mega_tour_pro_slider_content_type(),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_slider_section',
		'choices'			=> mega_tour_pro_page_choices(),
		'active_callback'	=> 'mega_tour_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_slider_section',
		'choices'			=> mega_tour_pro_post_choices(),
		'active_callback'	=> 'mega_tour_pro_is_slider_section_content_post_enable',
	) ) );

	// Slider trips drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Chooser( $wp_customize, 'mega_tour_pro_theme_options[slider_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'mega-tour-pro' ), $i ),
		'section'           => 'mega_tour_pro_slider_section',
		'choices'			=> mega_tour_pro_trip_choices(),
		'active_callback'	=> 'mega_tour_pro_is_slider_section_content_trip_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'mega_tour_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'mega-tour-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_slider_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[slider_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[slider_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_slider_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[slider_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[slider_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_slider_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'mega_tour_pro_theme_options[slider_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Mega_Tour_Pro_Dropdown_Taxonomies_Control( $wp_customize,'mega_tour_pro_theme_options[slider_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'mega-tour-pro' ),
	'section'           => 'mega_tour_pro_slider_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'mega_tour_pro_is_slider_section_content_destination_enable'
) ) );


// Slider btn label setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_label'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[slider_btn_label]', array(
	'label'           	=> esc_html__( 'Slider Button Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_slider_section',
	'active_callback' 	=> 'mega_tour_pro_is_slider_btn_section_enable',
	'type'				=> 'text',
) );

// Slider video btn label setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_video_label]', array(
	'default'			=> $options['slider_video_label'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[slider_video_label]', array(
	'label'           	=> esc_html__( 'Slider Video Label', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_slider_section',
	'active_callback' 	=> 'mega_tour_pro_is_slider_btn_section_enable',
	'type'				=> 'text',
) );

// Slider video btn url setting and control
$wp_customize->add_setting( 'mega_tour_pro_theme_options[slider_video_url]', array(
	'sanitize_callback' => 'esc_url_raw',
	'default'			=>'#'
) );

$wp_customize->add_control( 'mega_tour_pro_theme_options[slider_video_url]', array(
	'label'           	=> esc_html__( 'Slider Video Url', 'mega-tour-pro' ),
	'section'        	=> 'mega_tour_pro_slider_section',
	'active_callback' 	=> 'mega_tour_pro_is_slider_btn_section_enable',
	'type'				=> 'url',
) );