<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function mega_tour_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-tour-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function mega_tour_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-tour-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function mega_tour_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'mega-tour-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'mega_tour_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function mega_tour_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'mega-tour-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'mega-tour-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'mega-tour-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'mega-tour-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'mega-tour-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'mega-tour-pro' ),
            'header-font-6'   => esc_html__( 'Playfair Display', 'mega-tour-pro' ),
        );

        $output = apply_filters( 'mega_tour_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function mega_tour_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'mega-tour-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'mega-tour-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'mega-tour-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'mega-tour-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'mega-tour-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'mega-tour-pro' ),
        );

        $output = apply_filters( 'mega_tour_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function mega_tour_pro_selected_sidebar() {
        $mega_tour_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'mega-tour-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'mega-tour-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'mega-tour-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'mega-tour-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'mega-tour-pro' ),
        );

        $output = apply_filters( 'mega_tour_pro_selected_sidebar', $mega_tour_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function mega_tour_pro_site_layout() {
        $mega_tour_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'mega_tour_pro_site_layout', $mega_tour_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function mega_tour_pro_global_sidebar_position() {
        $mega_tour_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'mega_tour_pro_global_sidebar_position', $mega_tour_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function mega_tour_pro_sidebar_position() {
        $mega_tour_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'mega_tour_pro_sidebar_position', $mega_tour_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'mega_tour_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function mega_tour_pro_pagination_options() {
        $mega_tour_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'mega-tour-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'mega-tour-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'mega-tour-pro' ),
        );

        $output = apply_filters( 'mega_tour_pro_pagination_options', $mega_tour_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function mega_tour_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'mega-tour-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'mega-tour-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'mega-tour-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'mega-tour-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'mega-tour-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'mega-tour-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'mega-tour-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'mega-tour-pro' ),
        );
        return apply_filters( 'mega_tour_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mega_tour_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'mega-tour-pro' ),
            'off'       => esc_html__( 'Disable', 'mega-tour-pro' )
        );
        return apply_filters( 'mega_tour_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function mega_tour_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'mega-tour-pro' ),
            'off'       => esc_html__( 'No', 'mega-tour-pro' )
        );
        return apply_filters( 'mega_tour_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function mega_tour_pro_sortable_sections() {
        $sections = array(
            'slider'                => esc_html__( 'Main Slider', 'mega-tour-pro' ),
            'service'               => esc_html__( 'Service', 'mega-tour-pro' ),
            'popular_destination'   => esc_html__( 'Popular Destination', 'mega-tour-pro' ),
            'about'                 => esc_html__( 'About Us', 'mega-tour-pro' ),
            'featured'              => esc_html__( 'Featured', 'mega-tour-pro' ),
            'package'               => esc_html__( 'Package', 'mega-tour-pro' ),
            'cta'                   => esc_html__( 'CTA', 'mega-tour-pro' ),
            'gallery'               => esc_html__( 'Gallery', 'mega-tour-pro' ),
            'testimonial'           => esc_html__( 'Testimonial', 'mega-tour-pro' ),
            'team'                  => esc_html__( 'Team', 'mega-tour-pro' ),
            'blog_featured'         => esc_html__( 'Blog Featured', 'mega-tour-pro' ),
            'partner'               => esc_html__( 'Partner', 'mega-tour-pro' ),
            'blog'                  => esc_html__( 'Blog', 'mega-tour-pro' ),
            'subscription'          => esc_html__( 'Subscription', 'mega-tour-pro' ),
        );
        return apply_filters( 'mega_tour_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_slider_content_type' ) ) :
    /**
     * slider Options
     * @return array site slider options
     */
    function mega_tour_pro_slider_content_type() {
      
        $mega_tour_pro_slider_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' )) {
            $mega_tour_pro_slider_content_type = array_merge( $mega_tour_pro_slider_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-tour-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_slider_content_type', $mega_tour_pro_slider_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_service_content_type' ) ) :
    /**
     * service Options
     * @return array site service options
     */
    function mega_tour_pro_service_content_type() {
        $mega_tour_pro_service_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_pro_service_content_type = array_merge( $mega_tour_pro_service_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_service_content_type', $mega_tour_pro_service_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_about_content_type' ) ) :
    /**
     * about Options
     * @return array site about options
     */
    function mega_tour_pro_about_content_type() {
        $mega_tour_pro_about_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'custom'  => esc_html__( 'Custom', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_pro_about_content_type = array_merge( $mega_tour_pro_about_content_type, array(
                'trip'    => esc_html__( 'Trips', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_about_content_type', $mega_tour_pro_about_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function mega_tour_pro_featured_content_type() {
        $mega_tour_pro_featured_content_type = array(
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_pro_featured_content_type = array_merge( $mega_tour_pro_featured_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_featured_content_type', $mega_tour_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_popular_destination_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function mega_tour_pro_popular_destination_content_type() {
        $mega_tour_pro_popular_destination_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_pro_popular_destination_content_type = array_merge( $mega_tour_pro_popular_destination_content_type, array(
                'trip'          => esc_html__( 'Trip', 'mega-tour-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_popular_destination_content_type', $mega_tour_pro_popular_destination_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_package_content_type' ) ) :
    /**
     * Package Options
     * @return array site gallery options
     */
    function mega_tour_pro_package_content_type() {
        $mega_tour_pro_package_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_pro_package_content_type = array_merge( $mega_tour_pro_package_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_package_content_type', $mega_tour_pro_package_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'mega_tour_pro_cta_content_type' ) ) :
    /**
     * cta Options
     * @return array site cta options
     */
    function mega_tour_pro_cta_content_type() {
        $mega_tour_pro_cta_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'custom'    => esc_html__( 'Custom', 'mega-tour-pro' ),
        );

        $output = apply_filters( 'mega_tour_pro_cta_content_type', $mega_tour_pro_cta_content_type );
        return $output;
    }
endif;
if ( ! function_exists( 'mega_tour_pro_gallery_content_type' ) ) :
    /**
     * Package Options
     * @return array site gallery options
     */
    function mega_tour_pro_gallery_content_type() {
        $mega_tour_pro_gallery_content_type = array(
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $mega_tour_pro_gallery_content_type = array_merge( $mega_tour_pro_gallery_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_gallery_content_type', $mega_tour_pro_gallery_content_type );

        return $output;
    }
endif;
if ( ! function_exists( 'mega_tour_pro_blog_content_type' ) ) :
    /**
     * Package Options
     * @return array site blog options
     */
    function mega_tour_pro_blog_content_type() {
        $options = mega_tour_pro_get_theme_options();
        $mega_tour_pro_blog_content_type = array(
            'page'      => esc_html__( 'Page', 'mega-tour-pro' ),
            'post'      => esc_html__( 'Post', 'mega-tour-pro' ),
            'category'  => esc_html__( 'Category', 'mega-tour-pro' ),
            'recent' 	=> esc_html__( 'Recent', 'mega-tour-pro' ),
        );

        if ( class_exists( 'WP_Travel' )) {
            $mega_tour_pro_blog_content_type = array_merge( $mega_tour_pro_blog_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'mega-tour-pro' ),
                'destination'   => esc_html__( 'Destination', 'mega-tour-pro' ),
                'activity'      => esc_html__( 'Activity', 'mega-tour-pro' ),
                ) );
        }

        $output = apply_filters( 'mega_tour_pro_blog_content_type', $mega_tour_pro_blog_content_type );

        return $output;
    }
endif;