<?php
/**
 * Blog section
 *
 * This is the template for the content of Blog section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_blog_section' ) ) :
    /**
    * Add Blog section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_blog_section() {
        $options = mega_tour_pro_get_theme_options();
        
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'mega_tour_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get Blog section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_blog_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        switch ( $options['home_layout'] ) {
            case 'default-design':
                 // Render Default blog section now.
                mega_tour_pro_render_blog_section( $section_details );
                break;
            
            case 'third-design':
                // Render Business blog section now.
                mega_tour_pro_render_business_blog_section( $section_details );
                break;
            case 'fourth-design':
                // Render Blog blog section now.
                mega_tour_pro_render_blog_design_section( $section_details );
                break;
            
            default:
             // Render Defualt blog section now.
                mega_tour_pro_render_blog_section( $section_details );
        }
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_blog_section_details' ) ) :
    /**
    * Blog section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input Blog section details.
    */
    function mega_tour_pro_get_blog_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        $blog_content_type  = $options['blog_content_type']; // Content type.
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 3; // Blog Count.
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

			case 'trip-types': // trip-types
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['blog_content_trip_types'] ) ? $options['blog_content_trip_types'] : array();

				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'itinerary_types',
							'field'    => 'id',
							'terms'    => (array) $cat_id,
						),
					),
					'posts_per_page'  => absint( $blog_count ),
					);
                $content['taxonomy'] = 'itinerary_types';
			break;

			
			case 'destination': //Destination
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['blog_content_destination'] ) ? $options['blog_content_destination'] : array();
				
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'travel_locations',
							'field'    => 'id',
							'terms'    => (array) $cat_id,
						),
					),
					'posts_per_page'  => absint( $blog_count ),
					); 
				$content['taxonomy'] = 'travel_locations';
			break;

			case 'activity':
				if ( ! class_exists( 'WP_Travel' ) )
					return;
				
				$cat_id = ! empty( $options['blog_content_activity'] ) ? $options['blog_content_activity'] : array();
                
                if ( empty( $cat_id ) )
                    return;
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'activity',
							'field'    => 'id',
							'terms'    => (array) $cat_id,
						),
					),
					'posts_per_page'  => absint( $blog_count ),
					); 
                $content['taxonomy'] = 'activity';
			break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']            = get_the_id();
                $page_post['title']         = get_the_title();
                $page_post['url']           = get_the_permalink();
                $page_post['excerpt']       = ($options['home_layout'] == 'third-design') ? mega_tour_pro_trim_content( 15 ) : mega_tour_pro_trim_content( 60 );
                $page_post['image']         = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg'; 
                $page_post['image_full']    = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '#'; 

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Blog section content details.
add_filter( 'mega_tour_pro_filter_blog_section_details', 'mega_tour_pro_get_blog_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_blog_section' ) ) :
  /**
   * Start Blog section
   *
   * @return string Blog content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_blog_section( $content_details = array() ) {
        $options            = mega_tour_pro_get_theme_options();
        $blog_taxonomy      = isset($content_details['taxonomy']) ? $content_details['taxonomy'] : 'category';
        $blog_content_type  = $options['blog_content_type'];
        $blog_btn_title     = ! empty( $options['blog_btn_title'] ) ? $options['blog_btn_title'] : esc_html__( 'Read All Articles', 'mega-tour-pro' );
        $blog_btn_url       = ! empty( $options['blog_btn_url'] ) ? $options['blog_btn_url'] : '';
        $blog_title         = ! empty( $options['blog_title'] ) ? $options['blog_title'] : esc_html__( 'Read Our Travel Blog', 'mega-tour-pro' );
        $blog_sub_title     = ! empty( $options['blog_sub_title'] ) ? $options['blog_sub_title'] : esc_html('Our Blog','mega-tour-pro');
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="mega_tour_pro_blog_section">
             <div id="latest-posts" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <div id="blog-header"  class="section-header">
                        <p class="subtitle"><?php echo esc_html($blog_sub_title); ?></p>
                        <h2 class="section-title"><?php echo esc_html($blog_title); ?></h2>
                    </div><!-- .section-header -->
                    <?php if(!empty($blog_btn_title) && !empty($blog_btn_url)): ?>
                    <div id="blog-read-more" class="read-more">
                        <a href="<?php echo esc_url($blog_btn_url); ?>" class="btn more-link"><?php echo esc_html($blog_btn_title); ?></a>
                    </div><!-- .read-more -->
                    <?php endif; ?>
                </div><!-- .section-header-wrapper -->

                <div class="archive-blog-wrapper clear col-3">
                    <?php foreach($content_details['details'] as $i => $content): ?>
                    <article class="has-post-thumbnail">
                        <div class="post-item-wrapper">
                            <div class="featured-image">
                                <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="latest-post-<?php echo esc_attr($i); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo $content['url']; ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php mega_tour_pro_posted_on($content['id']); ?>
                                    <span class="cat-links">
                                        <?php the_terms($content['id'], $blog_taxonomy); ?>
                                    </span><!-- .cat-links -->
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </div><!-- .post-item-wrapper -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .archive-blog-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->
        </div>
       
    <?php }
endif;


if ( ! function_exists( 'mega_tour_pro_render_business_blog_section' ) ) :
  /**
   * Start Business Blog section
   *
   * @return string Blog content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_business_blog_section( $content_details = array() ) {
        $options            = mega_tour_pro_get_theme_options();
        $blog_taxonomy      = isset($content_details['taxonomy']) ? $content_details['taxonomy'] : 'category';
        $blog_content_type  = $options['blog_content_type'];
        $blog_btn_title     = ! empty( $options['blog_btn_title'] ) ? $options['blog_btn_title'] : esc_html__( 'Read All Articles', 'mega-tour-pro' );
        $blog_btn_url       = ! empty( $options['blog_btn_url'] ) ? $options['blog_btn_url'] : '';
        $blog_title         = ! empty( $options['blog_title'] ) ? $options['blog_title'] : esc_html__( 'Read Our Travel Blog', 'mega-tour-pro' );
        $blog_description   = ! empty( $options['blog_description'] ) ? $options['blog_description'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="mega_tour_pro_blog_section">
            <div id="business-latest-posts" class="relative page-section">
                <div class="wrapper">
                    <div id="blog-header" class="business-section-header">
                        <h2 class="business-section-title"><?php echo esc_html($blog_title); ?></h2>
                        <p class="business-section-subtitle"><?php echo wp_kses_post($blog_description); ?></p>
                    </div><!-- .business-section-header -->

                    <div class="business-section-content clear col-3">
                    <?php foreach($content_details['details'] as $i => $content): ?>
                        <article class="has-post-thumbnail">
                            <div class="business-post-item">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="latest-post-<?php echo esc_attr($i); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo $content['url']; ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->

                                    <div class="entry-meta clear">
                                        <?php mega_tour_pro_posted_on($content['id']); ?>
                                        
                                        <?php if(!empty($blog_btn_title)): ?>
                                            <span id="blog-read-more" class="more-link"><a href="<?php echo $content['url']; ?>" class="more-link"><?php echo esc_html($blog_btn_title); ?></a></span>
                                        <?php endif; ?>

                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </div><!-- .business-post-item -->
                        </article>
                        <?php endforeach; ?>

                    </div><!-- .business-section-content -->
                </div><!-- .wrapper -->
            </div><!-- #business-latest-posts -->
        </div>

       
    <?php }
endif;

if ( ! function_exists( 'mega_tour_pro_render_blog_design_section' ) ) :
  /**
   * Start Blog Design Blog section
   *
   * @return string Blog Design Blog content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_blog_design_section( $content_details = array() ) {
        $options        = mega_tour_pro_get_theme_options();
        $blog_btn_title = ! empty( $options['blog_btn_title'] ) ? $options['blog_btn_title'] : esc_html__( 'Continue Reading', 'mega-tour-pro' );

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="mega_tour_pro_blog_section">
            <div id="blog-latest-posts" class="relative page-section">
                <div class="wrapper">
                    <div id="primary" class="content-area">
                        <main id="main" class="site-main" role="main">
                        <?php foreach($content_details['details'] as $i => $content):
                                $category = get_the_category($content['id']); 
                            ?>
                            <article>
                                <div class="blog-post-wrapper">
                                    <?php if( ! empty( $category ) && ! is_wp_error( $category ) ) : ?>
                                        <span class="cat-links">
                                            <a href="<?php echo esc_url(get_category_link($category[0]->term_id)); ?>" tabindex="0"><?php echo esc_html($category[0]->cat_name); ?></a>                                    
                                        </span><!-- .cat-links -->
                                    <?php endif; ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo $content['url']; ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>
                                    
                                    <?php mega_tour_pro_posted_on($content['id']); ?>

                                    <?php if(has_post_thumbnail($content['id'])): ?>
                                        <div class="featured-image">
                                            <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image_full']); ?>" alt="latest-post-<?php echo esc_attr($i); ?>"></a>
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->

                                    <?php if(!empty($blog_btn_title)): ?>
                                        <div id="blog-read-more" class="read-more">
                                            <a href="<?php echo $content['url']; ?>" class="more-link"><?php echo esc_html($blog_btn_title); ?></a>
                                            <span class="more-line"></span>
                                        </div><!-- .read-more  -->
                                    <?php endif; ?>

                                    <?php if($options['blog_social_menu_enable'] && has_nav_menu('social')) : ?>
                                        <div class="post-footer-share">
                                        <?php
                                            wp_nav_menu( array(
                                                'theme_location' => 'social',
                                                'menu_class' => 'social-icons',
                                                'echo' => true,
                                                'link_before' => '<span class="screen-reader-text">',
                                                'link_after' => '</span>',
                                            ) );
                                        ?>
                                        </div><!-- .post-footer-share -->
                                    <?php endif; ?>
                                </div><!-- .blog-post-wrapper -->
                            </article>
                        <?php endforeach; ?>
                        </main><!-- #main -->
                    </div><!-- #primary -->
                    <?php  
                    if ( mega_tour_pro_is_sidebar_enable()) {
                        get_sidebar();
                    }
                    ?>
                </div><!-- .wrapper -->
            </div><!-- #bog-latest-posts -->
        </div>
      
    <?php }
endif;