<?php
/**
 * Partner section
 *
 * This is the template for the content of Partner section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_partner_section' ) ) :
    /**
    * Add Partner section
    *
    *@since Mega Tour Pro 1.0.0
    */
    function mega_tour_pro_add_partner_section() {
        $options = mega_tour_pro_get_theme_options();
        
        // Check if Partner is enabled on frontpage
        $partner_enable = apply_filters( 'mega_tour_pro_section_status', true, 'partner_section_enable' );
        
        if($options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design'){
            $partner_enable = false;
        }
        if ( true !== $partner_enable ) {
            return false;
        }
        // Get Partner section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_pro_filter_partner_section_details', $section_details );

        if ( empty( $section_details ) ) {
           return;
        }

        // Render Partner section now.
        mega_tour_pro_render_partner_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_pro_get_partner_section_details' ) ) :
    /**
    * Partner section details.
    *
    * @since Mega Tour Pro 1.0.0
    * @param array $input Partner section details.
    */
    function mega_tour_pro_get_partner_section_details( $input ) {
        $options = mega_tour_pro_get_theme_options();

        
        $partner_content_type   = $options['partner_content_type']; // Partner Content type.
        $partner_count          = ! empty( $options['partner_count'] ) ? $options['partner_count'] : 4; // Partner Post Count
        
        $content = array();
        switch ( $partner_content_type ) {
        	
            case 'category':
                $cat_id = ! empty( $options['partner_content_category'] ) ? $options['partner_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $partner_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    if ( ! empty( $options['partner_content_page_' . $i] ) )
                        $page_ids[] = $options['partner_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $partner_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    if ( ! empty( $options['partner_content_post_' . $i] ) )
                        $post_ids[] = $options['partner_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $partner_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $partner_count; $i++ ) {
                    $custom['id']           = $i;
                    $custom['image']        = ! empty( $options['partner_image_' . $i] ) ? $options['partner_image_' . $i] : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    $custom['url']          = ! empty( $options['partner_link_' . $i] ) ? $options['partner_link_' . $i] : '';
                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            default:
            break;
        }

        if ( 'custom' !== $partner_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        endif;
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;

// Partner section content details.
add_filter( 'mega_tour_pro_filter_partner_section_details', 'mega_tour_pro_get_partner_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_partner_section' ) ) :
  /**
   * Start Partner section
   *
   * @return string Partner content
   * @since Mega Tour Pro 1.0.0
   *
   */
   function mega_tour_pro_render_partner_section( $content_details = array() ) {
        $options                = mega_tour_pro_get_theme_options();
        $partner_content_type   = $options['partner_content_type'];
        $partner_count          = ! empty( $options['partner_count'] ) ? $options['partner_count'] : 4;
        $partner_auto_play      = ($options['partner_auto_play'] == true ) ? 'true' : 'false';
        $partner_sub_title      = ! empty( $options['partner_sub_title'] ) ? $options['partner_sub_title'] : esc_html__( 'Clients', 'mega-tour-pro' );
        $partner_title          = ! empty( $options['partner_title'] ) ? $options['partner_title'] : esc_html__( 'Our Happy Partners', 'mega-tour-pro' );
        $partner_bg_image       = ! empty( $options['partner_bg_image'] ) ? $options['partner_bg_image'] : get_template_directory_uri().'/assets/uploads/our-partners-bg.jpg';
        if ( empty( $content_details ) ) {
           return;
        } ?>
        <div id="mega_tour_pro_partner_section">
            <div id="our-partners" class="relative page-section section-header-enabled" style="background-image: url(<?php echo esc_url($partner_bg_image); ?>);">
                <div class="overlay"></div>
                <div class="wrapper">
                    <header class="section-header">
                        <p class="subtitle"><?php echo esc_html($partner_sub_title); ?></p>
                        <h2 class="section-title"><?php echo esc_html($partner_title); ?></h2>
                    </header>
                    <div class="client-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":true, "autoplay": <?php echo esc_attr($partner_auto_play);?>, "draggable": true, "fade": false }'>
                    
                    <?php foreach($content_details as $i =>$content): ?>    
                    <article>
                        <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="partner-0<?php echo $i;?>"></a>
                    </article>
                    <?php endforeach; ?>
                    
                    </div><!-- .client-slider -->
                </div><!-- .wrapper -->
            </div><!-- #our-partenrs -->
        </div>
        

    <?php }
endif;