<?php
/**
 * Popular Destination section
 *
 * This is the template for the content of popular Destination section
 *
 * @package Theme Palace
 * @subpackage Mega Tour Pro
 * @since Mega Tour Pro 1.0.0
 */
if ( ! function_exists( 'mega_tour_pro_add_popular_destination_section' ) ) :
	/**
	* Add popular Destination section
	*
	*@since Mega Tour Pro 1.0.0
	*/
	function mega_tour_pro_add_popular_destination_section() {
		$options = mega_tour_pro_get_theme_options();

			// Check if Destination is enabled on frontpage
			$popular_destination_enable = apply_filters( 'mega_tour_pro_section_status', true, 'popular_destination_section_enable' );
			
			if($options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design'){
				$popular_destination_enable = false;
			}
			if ( true !== $popular_destination_enable ) {
				return false;
			}
			// Get Destination section details
			$section_details = array();
			$section_details = apply_filters( 'mega_tour_pro_filter_popular_destination_section_details', $section_details );
			if ( empty( $section_details ) ) {
				return;
			}

			// Render Destination section now.
			mega_tour_pro_render_popular_destination_section( $section_details );
		}
endif;

if ( ! function_exists( 'mega_tour_pro_get_popular_destination_section_details' ) ) :
	/**
	* Popular Destination section details.
	*
	* @since Mega Tour Pro 1.0.0
	* @param array $input popular destination section details.
	*/
	function mega_tour_pro_get_popular_destination_section_details( $input ) {
		$options = mega_tour_pro_get_theme_options();

		// Content type.
		$popular_destination_content_type  = $options['popular_destination_content_type'];
		$popular_destination_count = ! empty( $options['popular_destination_count'] ) ? $options['popular_destination_count'] : 3;
		
		$content 		= array();
		$args 			= array();
        $content['cats'] = array();
		switch ( $popular_destination_content_type ) {
		
			case 'category':
				$cat_id = ! empty( $options['popular_destination_content_category'] ) ? $options['popular_destination_content_category'] : '';
				$args = array(
					'post_type'         	=> 'post',
					'posts_per_page'    	=> absint( $popular_destination_count ),
					'cat'               	=> absint( $cat_id ),
					'ignore_sticky_posts'   => true,
					);                    
			break;

			case 'page':
				$page_ids = array();

				for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
					if ( ! empty( $options['popular_destination_content_page_' . $i] ) )
						$page_ids[] = $options['popular_destination_content_page_' . $i];
				}
				
				$args = array(
					'post_type'         => 'page',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $popular_destination_count ),
					'orderby'           => 'post__in',
					);                    
			break;

			case 'post':
				$post_ids = array();

				for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
					if ( ! empty( $options['popular_destination_content_post_' . $i] ) )
						$post_ids[] = $options['popular_destination_content_post_' . $i];
				}
				$args = array(
					'post_type'         	=> 'post',
					'post__in'          	=> ( array ) $post_ids,
					'posts_per_page'    	=> absint( $popular_destination_count ),
					'orderby'           	=> 'post__in',
					'ignore_sticky_posts'   => true,
					);                    
			break;

			case 'trip':
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$page_ids = array();

				for ( $i = 1; $i <= $popular_destination_count; $i++ ) {
					if ( ! empty( $options['popular_destination_content_trip_' . $i] ) )
						$page_ids[] = $options['popular_destination_content_trip_' . $i];
				}
				
				$args = array(
					'post_type'         => 'itineraries',
					'post__in'          => ( array ) $page_ids,
					'posts_per_page'    => absint( $popular_destination_count ),
					'orderby'           => 'post__in',
					);   

				$content['taxonomy'] = 'travel_locations';

			break;

			case 'trip-types': // trip-types
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['popular_destination_content_trip_types'] ) ? $options['popular_destination_content_trip_types'] : array();

				$args = array(
					'post_type' => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'itinerary_types',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $popular_destination_count ),
					);

                $content['taxonomy'] = 'itinerary_types';
			break;

			
			case 'destination': //Destination
				if ( ! class_exists( 'WP_Travel' ) )
					return;

				$cat_id = ! empty( $options['popular_destination_content_destination'] ) ? $options['popular_destination_content_destination'] : array();
				
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'travel_locations',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $popular_destination_count ),
					); 

				$content['taxonomy'] = 'travel_locations';
			break;

			case 'activity':
				if ( ! class_exists( 'WP_Travel' ) )
					return;
				
				$cat_id = ! empty( $options['popular_destination_content_activity'] ) ? $options['popular_destination_content_activity'] : array();
				
				if ( empty( $cat_id ) )
                    return;
				$args = array(
					'post_type'      => 'itineraries',
					'tax_query' => array(
						array(
							'taxonomy' => 'activity',
							'field'    => 'id',
							'terms'    => $cat_id,
						),
					),
					'posts_per_page'  => absint( $popular_destination_count ),
					); 

                $content['taxonomy'] = 'activity';
			break;

			default:
			break;
		}

		$content['details'] = array();
		$query = new WP_Query( $args );
		if ( $query->have_posts() ) : 
			while ( $query->have_posts() ) : $query->the_post();
				$page_post['id']        = get_the_id();
				$page_post['title']     = get_the_title();
				$page_post['url']       = get_the_permalink();
				$page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
				// Push to the main array.
				array_push( $content['details'], $page_post );
			endwhile;
		endif;

		wp_reset_postdata();
		if ( ! empty( $content ) ) {
				$input = $content;
		}
		return $input;
	}
endif;

// Destination section content details.
add_filter( 'mega_tour_pro_filter_popular_destination_section_details', 'mega_tour_pro_get_popular_destination_section_details' );


if ( ! function_exists( 'mega_tour_pro_render_popular_destination_section' ) ) :
	/**
	 * Start Destination section
	 *
	 * @return string Destination content
	 * @since Mega Tour Pro 1.0.0
	 *
	 */
	 function mega_tour_pro_render_popular_destination_section( $content_details = array() ) {
		$options = mega_tour_pro_get_theme_options();

		$popular_destination_content_type  	= $options['popular_destination_content_type'];
		$popular_destination_sub_title 		= !empty($options['popular_destination_sub_title']) ? $options['popular_destination_sub_title'] : esc_html__('Where To Go','mega-tour-pro');
		$popular_destination_title 			= !empty($options['popular_destination_title']) ? $options['popular_destination_title'] : esc_html__('Popular Destinations','mega-tour-pro');
		$popular_destination_btn_label 		= !empty($options['popular_destination_btn_label']) ? $options['popular_destination_btn_label'] : esc_html__('Let’s Travel Now','mega-tour-pro');

		if ( empty( $content_details ) ) {
				return;
		} ?>
		<div id="mega_tour_pro_popular_destination_section">
			<div id="popular-destinations" class="relative page-section">
				<div class="wrapper">
					<div class="section-header">
						<p class="subtitle"><?php echo esc_html($popular_destination_sub_title); ?></p>
						<h2 class="section-title"><?php echo esc_html($popular_destination_title); ?></h2>
					</div><!-- .section-header -->
				</div><!-- .wrapper -->

				<div class="wrapper popular-destination-wrapper">
					<div class="destination-slider"
						data-slick='{"slidesToShow": <?php echo absint($options['popular_destination_column_type']); ?>, "slidesToScroll": 1, "infinite": false, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
						
						<?php foreach ($content_details['details'] as $content): 
						$taxonomy = isset($content_details['taxonomy']) ? $content_details['taxonomy'] : 'category';
						$terms =  get_the_terms( $content['id'], $taxonomy);
						?>
						<article>
							<div class="featured-image"
								style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
								<div class="overlay"></div>

								<?php if($options['home_layout'] == 'second-design') echo '</div>'; ?><!-- .featured-image -->
								<?php if ( ! in_array( $popular_destination_content_type, array( 'category', 'page', 'post' ) ) && class_exists( 'WP_Travel' )  ) :  ?>
									<div class="top-details">
									<?php if ( mega_tour_pro_wptravel_tab_show_in_menu( 'reviews' ) ) :
										$average_rating = mega_tour_pro_wptravel_get_average_rating( $content['id'] ); ?>
										<div class="wp-travel-average-review"
											title="<?php printf( esc_attr__( 'Rated %s out of 5', 'mega-tour-pro' ), $average_rating ); ?>">
											<span style="width:<?php echo esc_attr( ( $average_rating / 5 ) * 100 ); ?>%">
												<strong itemprop="ratingValue"
													class="rating"><?php echo esc_html( $average_rating ); ?></strong>
												<?php printf( esc_html__( 'out of %1$s5%2$s', 'mega-tour-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
											</span>
										</div>
										<?php endif; ?>

										<div class="trip-price">
											<span>
												<?php
												$trip_price = WP_Travel_Helpers_Pricings::get_price( array('trip_id'=>$content['id']) );
												echo mega_tour_pro_wptravel_get_formated_price_currency( $trip_price ); ?>
											</span>
										</div><!-- .trip-price -->
									</div><!-- .top-details -->
								<?php endif; ?>

									<div class="bottom-details">
										<header class="entry-header">

										<?php if( ! empty( $terms ) && ! is_wp_error( $terms ) ) : ?>
											<p class="location"><a href="<?php echo esc_url(get_term_link($terms[0]->term_id, $taxonomy)); ?>" style="color:white;"><?php echo esc_html($terms[0]->name); ?></a></p>
										<?php endif; ?>
										
											<h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
										</header>

										<div class="read-more">
											<a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($popular_destination_btn_label); ?></a>
										</div><!-- .read-more -->
									</div><!-- .bottom-details -->
							<?php if($options['home_layout'] == 'default-design') echo '</div>'; ?><!-- .featured-image -->

						</article>
						<?php endforeach; ?>
					</div><!-- .destination-slider -->
				</div><!-- .wrapper -->
			</div><!-- #popular-destinations -->
		</div>
	
<?php }
endif;